"""
The `logger.py` module provides functionality to set up the logging configuration for the scraper.
"""

import logging


def setup_logging():
    """
    Sets up the logging configuration for the application.
    Configures the logging to output messages to both a file named 'scraper.log'
    and the standard output stream. The log messages include the timestamp, logger name,
    log level, and the actual log message.
    The log level is set to INFO, meaning that DEBUG and more verbose logs are ignored.
    The log format is:
    `%(asctime)s - %(name)s - %(levelname)s - %(message)s`

    Parameters
    ----------
    None

    Returns
    -------
    None
    """
    logging.basicConfig(
        level=logging.INFO,
        format="%(asctime)s - %(name)s - %(levelname)s - %(message)s",
        handlers=[logging.FileHandler("scraper.log"), logging.StreamHandler()],
    )
